@@ -13,6 +13,8 @@
 
 #include <QFileInfo>
 
+#include <KLocalizedString>
+
 #include "kicondialog.h"
 
 class KIconButtonPrivate
@@ -21,6 +23,8 @@ public:
     KIconButtonPrivate(KIconButton *qq, KIconLoader *loader);
     ~KIconButtonPrivate();
 
+    KIconDialog *dialog();
+
     // slots
     void _k_slotChangeIcon();
     void _k_newIconName(const QString &);
@@ -45,23 +49,27 @@ public:
  */
 
 KIconButton::KIconButton(QWidget *parent)
-    : QPushButton(parent), d(new KIconButtonPrivate(this, KIconLoader::global()))
+    : QPushButton(parent)
+    , d(new KIconButtonPrivate(this, KIconLoader::global()))
 {
     QPushButton::setIconSize(QSize(48, 48));
 }
 
+#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 104)
 KIconButton::KIconButton(KIconLoader *loader, QWidget *parent)
-    : QPushButton(parent), d(new KIconButtonPrivate(this, loader))
+    : QPushButton(parent)
+    , d(new KIconButtonPrivate(this, loader))
 {
     QPushButton::setIconSize(QSize(48, 48));
 }
+#endif
 
 KIconButtonPrivate::KIconButtonPrivate(KIconButton *qq, KIconLoader *loader)
     : q(qq)
 {
     m_bStrictIconSize = false;
     iconSize = 0; // let KIconLoader choose the default
-    buttonIconSize = -1; //When buttonIconSize is -1, iconSize will be used for the button
+    buttonIconSize = -1; // When buttonIconSize is -1, iconSize will be used for the button
 
     mGroup = KIconLoader::Desktop;
     mContext = KIconLoader::Application;
@@ -69,7 +77,11 @@ KIconButtonPrivate::KIconButtonPrivate(KIconButton *qq, KIconLoader *loader)
 
     mpLoader = loader;
     mpDialog = nullptr;
-    QObject::connect(q, &KIconButton::clicked, q, [this]() {_k_slotChangeIcon();});
+    QObject::connect(q, &KIconButton::clicked, q, [this]() {
+        _k_slotChangeIcon();
+    });
+
+    q->setToolTip(i18nc("@info:tooltip", "Select Icon…"));
 }
 
 KIconButtonPrivate::~KIconButtonPrivate()
@@ -77,6 +89,22 @@ KIconButtonPrivate::~KIconButtonPrivate()
     delete mpDialog;
 }
 
+KIconDialog *KIconButtonPrivate::dialog()
+{
+    if (!mpDialog) {
+#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 104)
+        mpDialog = new KIconDialog(mpLoader, q);
+#else
+        mpDialog = new KIconDialog(q);
+#endif
+        QObject::connect(mpDialog, &KIconDialog::newIconName, q, [this](const QString &iconName) {
+            _k_newIconName(iconName);
+        });
+    }
+
+    return mpDialog;
+}
+
 KIconButton::~KIconButton() = default;
 
 void KIconButton::setStrictIconSize(bool b)
@@ -126,13 +154,8 @@ void KIconButton::setIcon(const QString &icon)
     d->mIcon = icon;
     setIcon(QIcon::fromTheme(d->mIcon));
 
-    if (!d->mpDialog) {
-        d->mpDialog = new KIconDialog(d->mpLoader, this);
-        connect(d->mpDialog, &KIconDialog::newIconName, this, [this](const QString &iconName) { d->_k_newIconName(iconName); });
-    }
-
     if (d->mbUser) {
-        d->mpDialog->setCustomLocation(QFileInfo(d->mpLoader->iconPath(d->mIcon, d->mGroup, true)).absolutePath());
+        d->dialog()->setCustomLocation(QFileInfo(d->mpLoader->iconPath(d->mIcon, d->mGroup, true)).absolutePath());
     }
 }
 
@@ -154,13 +177,9 @@ const QString &KIconButton::icon() const
 
 void KIconButtonPrivate::_k_slotChangeIcon()
 {
-    if (!mpDialog) {
-        mpDialog = new KIconDialog(mpLoader, q);
-        QObject::connect(mpDialog, &KIconDialog::newIconName, q, [this](const QString &iconName) { _k_newIconName(iconName); });
-    }
-
-    mpDialog->setup(mGroup, mContext, m_bStrictIconSize, iconSize, mbUser);
-    mpDialog->showDialog();
+    dialog()->setup(mGroup, mContext, m_bStrictIconSize, iconSize, mbUser);
+    dialog()->setSelectedIcon(mIcon);
+    dialog()->showDialog();
 }
 
 void KIconButtonPrivate::_k_newIconName(const QString &name)
