@@ -277,6 +277,7 @@ KIconDialog::KIconDialog(QWidget *parent)
     installEventFilter(new ShowEventFilter(this));
 }
 
+#if KICONTHEMES_BUILD_DEPRECATED_SINCE(5, 104)
 KIconDialog::KIconDialog(KIconLoader *loader, QWidget *parent)
     : QDialog(parent)
     , d(new KIconDialogPrivate(this))
@@ -288,6 +289,7 @@ KIconDialog::KIconDialog(KIconLoader *loader, QWidget *parent)
 
     installEventFilter(new ShowEventFilter(this));
 }
+#endif
 
 void KIconDialogPrivate::init()
 {
@@ -652,12 +654,12 @@ QString KIconDialog::getIcon(KIconLoader::Group group,
                              int iconSize,
                              bool user,
                              QWidget *parent,
-                             const QString &caption)
+                             const QString &title)
 {
     KIconDialog dlg(parent);
     dlg.setup(group, context, strictIconSize, iconSize, user);
-    if (!caption.isEmpty()) {
-        dlg.setWindowTitle(caption);
+    if (!title.isEmpty()) {
+        dlg.setWindowTitle(title);
     }
 
     return dlg.openDialog();
