@@ -1,8 +1,8 @@
+#include <QApplication>
 #include <kiconloader.h>
-#include <qapplication.h>
 
-#include <QDebug>
 #include <QDate>
+#include <QDebug>
 #include <QElapsedTimer>
 #include <QPixmap>
 
@@ -22,15 +22,12 @@ int main(int argc, char *argv[])
         qDebug() << "queryIcons " << mGroup << "," << mContext;
         const QStringList filelist = mpLoader->queryIcons(mGroup, mContext);
         qDebug() << " -> found " << filelist.count() << " icons.";
-        int i = 0;
-        for (QStringList::ConstIterator it = filelist.begin();
-                it != filelist.end() /*&& i<10*/;
-                ++it, ++i) {
-            //qDebug() << ( i==9 ? "..." : (*it) );
-            mpLoader->loadIcon((*it), (KIconLoader::Group)mGroup);
+        // int i = 0;
+        for (const auto &icon : filelist) {
+            // qDebug() << ( i==9 ? "..." : (*it) );
+            mpLoader->loadIcon(icon, (KIconLoader::Group)mGroup);
             ++count;
         }
     }
     qDebug() << "Loading " << count << " icons took " << (float)(dt.elapsed()) / 1000 << " seconds";
 }
-
